<?php

/**
 * @file
 * Contains \Drupal\webfactory_master\Plugin\ChannelSourceInterface.
 */

namespace Drupal\webfactory_master\Plugin;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\webfactory_master\Entity\ChannelEntity;

/**
 * Specify channel source plugin behavior.
 *
 * @see \Drupal\webfactory_master\Annotation\ChannelSource
 * @see \Drupal\webfactory_master\Plugin\ChannelSourcePluginManager
 * @see \Drupal\webfactory_master\Plugin\Channel\ChannelSourceBase
 * @see plugin_api
 */
interface ChannelSourceInterface extends PluginInspectionInterface {

  /**
   * Initialize plugin with channel entity and specific settings.
   *
   * @param array $settings
   *   The channel entity.
   */
  public function setConfiguration(ChannelEntity $entity, array $settings);

  /**
   * Return entities according to settings.
   */
  public function entities();

  /**
   * Defines plugin settings form.
   *
   * @param array $form
   *   The form element.
   * @param FormStateInterface $form_state
   *   The form state element.
   */
  public function getSettingsForm(array $form, FormStateInterface $form_state);

  /**
   * Retrieve plugin settings to store in channel entity.
   *
   * @param array $form
   *   The form element.
   * @param FormStateInterface $form_state
   *   The form state element.
   */
  public function getSettings(array $form, FormStateInterface $form_state);

}
