<?php

/**
 * @file
 * Contains Drupal\webfactory_slave\Form\TableFiltersForm.
 */

namespace Drupal\webfactory_slave\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\webfactory_slave\Services\EntitySynchronizer;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the table filters form.
 */
class TableFiltersForm extends FormBase {

  /**
   * The rest services.
   *
   * @var mixed The specified service
   */
  private $entitySync;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('webfactory_slave.services.entity_synchronizer')
    );
  }

  /**
   * TableFiltersForm constructor.
   *
   * @param \Drupal\webfactory_slave\Services\EntitySynchronizer $entity_sync
   *   EntitySynchronizer service.
   */
  public function __construct(EntitySynchronizer $entity_sync) {
    $this->entitySync = $entity_sync;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'webfactory_slave_tablefilters_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $type_filter  = \Drupal::request()->get('type');
    $sync_filter  = \Drupal::request()->get('sync');
    $title_filter = \Drupal::request()->get('title');

    $channels = $this->entitySync->getChannels();

    $options = array();
    foreach ($channels as $machine_name => $channel) {
      $options[$machine_name] = $channel->label;
    }

    $opt_sync = array(
      'All'     => t('-- @any --', ['@any' => 'Any']),
      'new'     => t('New content'),
      'need'    => t('Need update'),
      'updated' => t('Up to date'),
    );

    $form['#method'] = 'get';
    $form_state->cleanValues();
    $form['#attributes'] = array('class' => 'views-exposed-form');

    $form['type'] = array(
      '#title' => 'Type',
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => $type_filter,
    );
    $form['sync'] = array(
      '#title' => 'Synchronized',
      '#type' => 'select',
      '#options' => $opt_sync,
      '#default_value' => $sync_filter,
    );
    $form['title'] = array(
      '#title' => 'Title',
      '#type' => 'textfield',
      '#default_value' => $title_filter,
    );

    $form['actions'] = array('#type' => 'actions');
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Apply'),
    );
    $form['actions']['reset'] = array(
      '#type' => 'submit',
      '#value' => t('Reset'),
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    \Drupal::logger('Webfactory')->info('Hello');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    \Drupal::logger('Webfactory')->info('Hello2');
  }

}
